@@ -194,9 +194,11 @@ class LogOut(flow.Action):
     
     def run(self, button):
         project = self.root().project()
-        os.remove(
-            "%s/kitsu_config.json" % project.get_user_folder()
-        )
+        kitsu_config = "%s/kitsu_config.json" % project.user_settings_folder()
+
+        if os.path.exists(kitsu_config):
+            os.remove(kitsu_config)
+
         project.log_out()
         
         return self.get_result(
@@ -221,18 +223,12 @@ class Admin(flow.Object):
     kitsu_server_url = flow.Param("").watched()
 
     project_settings = flow.Child(ProjectSettings)
-    settings = flow.Child(ContextualView)  # .ui(hidden=True)
+    settings = flow.Child(ContextualView)
     users = flow.Child(Users)
     
     user_environment = flow.Child(UserEnvironment).ui(expanded=False)
-    # bookmarks = flow.Child(Bookmarks)
-
     default_applications = flow.Child(DefaultRunners).ui(expanded=False).injectable()
-    enable_filesystem_operations = flow.BoolParam(True).ui(
-        label="Enable file system operations",
-        tooltip="Enable operations on the OS file system (creation, move, delete) \
-                when manipulating flow elements.",
-    )
+
     sites = flow.Child(Sites)
     process_jobs = flow.Child(Synchronize)
     login_page = flow.Child(LoginPage).ui(hidden=True)
@@ -270,22 +266,22 @@ class Admin(flow.Object):
                 else:
                     site_name = "default"
             child_value.set(site_name)
-        elif child_value is self.current_user_id:
-            # Check env
-            if "USER_NAME" in os.environ:
-                child_value.set(os.environ["USER_NAME"])
-                return
+        # elif child_value is self.current_user_id:
+        #     # Check env
+        #     if "USER_NAME" in os.environ:
+        #         child_value.set(os.environ["USER_NAME"])
+        #         return
             
-            # Check user file
-            user_file = os.path.join(self._project.get_user_folder(), "user.json")
-            if os.path.exists(user_file):
-                with open(user_file, "r") as f:
-                    user_config = json.load(f)
-                    child_value.set(user_config["username"])
-                    return
+        #     # Check user file
+        #     user_file = os.path.join(self._project.user_settings_folder(), "user.json")
+        #     if os.path.exists(user_file):
+        #         with open(user_file, "r") as f:
+        #             user_config = json.load(f)
+        #             child_value.set(user_config["username"])
+        #             return
 
-            # Return local user name otherwise
-            child_value.set(getpass.getuser())
+        #     # Return local user name otherwise
+        #     child_value.set(getpass.getuser())
 
 
 class Project(KitsuProject):
@@ -312,14 +308,18 @@ class Project(KitsuProject):
         return root_dir
 
     def set_user(self, username):
-        if self.get_user_folder() is not None:
-            user_file = os.path.join(self.get_user_folder(), "user.json")
+        project_settings_folder = self.project_settings_folder()
 
-            with open(user_file, "w+") as f:
-                user_config = dict(username=username)
-                json.dump(user_config, f)
-            
-            self.user.current_user_id.touch()
+        if not os.path.exists(project_settings_folder):
+            os.makedirs(project_settings_folder)
+
+        user_file = os.path.join(project_settings_folder, "current_user.json")
+
+        with open(user_file, "w+") as f:
+            user_config = dict(username=username)
+            json.dump(user_config, f)
+        
+        self.user.current_user_id.touch()
 
     def get_user(self):
         return self.user.current_user_id.get()
@@ -362,7 +362,7 @@ class Project(KitsuProject):
 
             if not logged_in:
                 try:
-                    f = open("%s/kitsu_config.json" % self.get_user_folder(), "r")
+                    f = open("%s/kitsu_config.json" % self.user_settings_folder(), "r")
                 except IOError:
                     logged_in = False
                 else:
@@ -386,27 +386,31 @@ class Project(KitsuProject):
         self.update_kitsu_host(self.admin.kitsu_server_url.get())
         success = self.kitsu_api.log_in(kitsu_id, kitsu_password)
 
-        # Save authentification tokens
-        if success:
+        if success:            
+            # Set current user
+            user_name = self.admin.users.get_user_name(kitsu_id)
+            
+            if not user_name:
+                # Create user profile if not registered
+                self.admin.users.add_user(kitsu_id)
+            
+            self.set_user(user_name)
+
+            # Create user folder at first login
+            user_settings_folder = self.user_settings_folder()
+            if not os.path.exists(user_settings_folder):
+                os.makedirs(user_settings_folder)
+
+            # Save authentification tokens
             tokens = self.kitsu_api.get_tokens()
             kitsu_config = {}
             kitsu_config["tokens"] = tokens
             kitsu_config["kitsu_host"] = self.kitsu_api.get_host()
 
-            user_folder = self.get_user_folder()
-            if user_folder is not None:
-                with open("%s/kitsu_config.json" % user_folder, "w+") as f:
+            if user_settings_folder is not None:
+                with open("%s/kitsu_config.json" % user_settings_folder, "w+") as f:
                     json.dump(kitsu_config, f)
 
-            # Set current user
-            user_name = self.admin.users.get_user_name(kitsu_id)
-            
-            if not user_name:
-                # User profile not registered, create it
-                self.admin.users.add_user(kitsu_id)
-            
-            self.set_user(user_name)
-
         return success
     
     def log_out(self):
@@ -434,11 +438,21 @@ class Project(KitsuProject):
         else:
             return None
 
-    def get_user_folder(self):
+    def project_settings_folder(self):
+        return os.path.join(
+            pathlib.Path.home(),
+            ".libreflow",
+            self.name()
+        )
+
+    def user_settings_folder(self):
         '''
         DEPRECATED ! TO DELETE ? 
         '''
-        return os.path.join(pathlib.Path.home(), ".libreflow")
+        return os.path.join(
+            self.project_settings_folder(),
+            self.get_user()
+        )
 
     def get_project_thumbnail2(self):
         image = self.admin.project_settings.project_thumbnail.get()
@@ -495,10 +509,6 @@ class Project(KitsuProject):
         if self._RUNNERS_FACTORY is None:
             self.ensure_runners_loaded()
 
-        user_folder = self.get_user_folder()
-        if user_folder is not None and not os.path.exists(user_folder):
-            os.mkdir(user_folder)
-
         self.update_user_environment()
 
         if self._show_login_page.get():
