@@ -249,6 +249,14 @@ class Revision(flow.Object):
                 ext=self._file.format.get(),
             )
             child_value.set(name)
+        elif child_value is self.playblast_path:
+            child_value.set(
+                os.path.join(
+                    os.path.dirname(self._file.get_path()),
+                    "preview",
+                    "%s_%s-movie.mov" % (self._file.complete_name.get(), self.name()),
+                )
+            )
 
 
 class ToggleSyncStatuses(flow.Action):
@@ -291,7 +299,7 @@ class Revisions(flow.Map):
         return flow.injection.injectable(Revision)
 
     def columns(self):
-        columns = ["Revision", "Created by", "On"]
+        columns = ["Revision", "Created by", "When"]
         
         if self._show_sync_statuses.get():
             if self._enable_short_names.get():
@@ -332,7 +340,7 @@ class Revisions(flow.Map):
             {
                 "Revision": item_name,
                 "Created by": item.user.get(),
-                "On": datetime.datetime.fromtimestamp(item.date.get()).ctime(),
+                "When": timeago.format(datetime.datetime.fromtimestamp(item.date.get()), datetime.datetime.now()),
                 "Comment": item.comment.get(),
             }
         )
@@ -977,6 +985,158 @@ class SearchExistingRevisions(flow.Action):
         revisions.touch()
 
 
+class RenderBlenderPlayblastAction(OpenWithBlenderAction):
+
+    _files = flow.Parent(2)
+    revision_name = flow.Param("", RevisionsChoiceValue).watched()
+
+    def _sequence_number_from_name(self, sequence_name):
+        tmp = re.findall(r"\d+", sequence_name)
+        numbers = list(map(int, tmp))
+        return numbers[0]
+
+    def get_buttons(self):
+        self.revision_name.revert_to_default()
+        return ["Render", "Publish first", "Cancel"]
+
+    def needs_dialog(self):
+        return True
+
+    def allow_context(self, context):
+        return (
+            super(RenderBlenderPlayblastAction, self).allow_context(context)
+            and not self._file.is_empty()
+        )
+    
+    def playblast_infos_from_revision(self, revision_name):
+        filepath = self._file.path.get()
+        filename = "_".join(self._file.name().split("_")[:-1])
+
+        playblast_filename = filename + "_movie"
+        playblast_revision_filename = self._file.complete_name.get() + "_movie.mov"
+        
+        playblast_filepath = os.path.join(
+            self.root().project().get_root(),
+            os.path.dirname(filepath),
+            playblast_filename + "_mov",
+            revision_name,
+            playblast_revision_filename
+        )
+
+        return playblast_filepath, playblast_filename
+
+    def child_value_changed(self, child_value):
+        if child_value is self.revision_name:
+            msg = "<h3>Render playblast</h3>"
+            playblast_path, _ = self.playblast_infos_from_revision(child_value.get())
+
+            # Check if revision playblast exists
+            if os.path.exists(playblast_path):
+                msg += (
+                    "<font color=#D50000>"
+                    "Choosing to render a revision's playblast"
+                    "will override the existing one."
+                    "</font>"
+                )
+
+            self.message.set(msg)
+
+    def extra_argv(self):
+        file_settings = get_contextual_dict(
+            self._file, "settings", ["sequence", "shot"]
+        )
+        project_name = self.root().project().name()
+        revision = self._file.get_revision(self.revision_name.get())
+        python_expr = """import bpy
+bpy.ops.lfs.playblast(do_render=True, filepath='%s', studio='%s', project='%s', sequence='s%04i', scene='%s')""" % (
+            self.output_path,
+            self.root().project().admin.current_site_name.get(),
+            project_name,
+            self._sequence_number_from_name(file_settings["sequence"]),
+            file_settings["shot"],
+        )
+
+        return [
+            "-b",
+            revision.get_path(),
+            "--addons",
+            "mark_sequence",
+            "--python-expr",
+            python_expr,
+        ]
+
+    def run(self, button):
+        if button == "Cancel":
+            return
+        elif button == "Publish first":
+            return self.get_result(
+                next_action=self._file.publish_and_render_playblast.oid()
+            )
+        
+        revision_name = self.revision_name.get()
+        playblast_path, playblast_name = self.playblast_infos_from_revision(
+            revision_name
+        )
+
+        # Get or create playblast file
+        if not self._files.has_mapped_name(playblast_name + "_mov"):
+            playblast_file = self._files.add_tracked_file(
+                name=playblast_name,
+                extension="mov",
+                complete_name=self._file.complete_name.get() + "_movie"
+            )
+        else:
+            playblast_file = self._files[playblast_name + "_mov"]
+        
+        # Get or add playblast revision
+        if playblast_file.has_revision(revision_name):
+            playblast_revision = playblast_file.get_revision(
+                revision_name
+            )
+        else:
+            playblast_revision = playblast_file.get_revisions().add(
+                name=revision_name
+            )
+        
+        # Configure playblast revision
+        revision = self._file.get_revision(revision_name)
+        playblast_revision.comment.set(revision.comment.get())
+        playblast_revision.set_sync_status("Available")
+
+        # Store revision path as playblast output path
+        self.output_path = playblast_revision.get_path().replace("\\", "/")
+        
+        # Ensure playblast revision folder exists and is empty
+        if not os.path.exists(playblast_revision.path.get()):
+            os.makedirs(playblast_revision.path.get())
+        elif os.path.exists(self.output_path):
+            os.remove(self.output_path)
+
+        super(RenderBlenderPlayblastAction, self).run(button)
+        self._files.touch()
+
+
+class PublishAndRenderPlayblastAction(PublishFileAction):
+
+    def allow_context(self, context):
+        return (
+            context
+            and self._file.format.get() == "blend"
+            and not self._file.is_empty()
+        )
+
+    def run(self, button):
+        if button == "Cancel":
+            return self.get_result(next_action=self._file.render_playblast.oid())
+
+        super(PublishAndRenderPlayblastAction, self).run(button)
+        published_revision = self._file.get_head_revision()
+
+        self._file.render_playblast.revision_name.set(published_revision.name())
+
+        return self._file.render_playblast.run("Render")
+
+
 class TrackedFile(File):
 
     ICON = ("icons.gui", "text-file-1")
@@ -1007,6 +1167,10 @@ class TrackedFile(File):
     lock_action = flow.Child(LockAction).ui(label="Lock")
     unlock_action = flow.Child(UnlockAction).ui(label="Unlock")
     search_existing_revisions = flow.Child(SearchExistingRevisions)
+    
+    with flow.group("Playblast"):
+        render_playblast = flow.Child(RenderBlenderPlayblastAction)
+        publish_and_render_playblast = flow.Child(PublishAndRenderPlayblastAction)
 
     with flow.group("Open with"):
         open_with_blender = flow.Child(OpenWithBlenderAction).ui(label="Blender")
@@ -1128,10 +1292,6 @@ class TrackedFile(File):
 
         revisions = self.get_revisions()
 
-        enable_os = (
-            self.root().project().admin.enable_filesystem_operations.get()
-        )  # Lovely
-
         # Overwrite current working copy
         try:
             working_copy = revisions[user_name]
@@ -1139,54 +1299,52 @@ class TrackedFile(File):
             # No working copy, will be created below
             pass
         else:
-            if enable_os:
-                try:
-                    shutil.rmtree(working_copy.path.get())
-                except FileNotFoundError:
-                    self.root().session().log_warning(
-                        "File '{}' no longer exists".format(working_copy.path.get())
-                    )
+            try:
+                shutil.rmtree(working_copy.path.get())
+            except FileNotFoundError:
+                self.root().session().log_warning(
+                    "File '{}' no longer exists".format(working_copy.path.get())
+                )
 
             revisions.remove(user_name)
 
         working_copy = revisions.add(user_name)
         working_copy.set_sync_status("Available")
 
-        if enable_os:
-            try:
-                os.makedirs(working_copy.path.get())
-            except OSError:
-                self.root().session().log_error(
-                    "Creation of working copy folder '%s' failed\n\n==> TRACEBACK\n"
-                    % working_copy.path.get()
-                )
-                raise
+        try:
+            os.makedirs(working_copy.path.get())
+        except OSError:
+            self.root().session().log_error(
+                "Creation of working copy folder '%s' failed\n\n==> TRACEBACK\n"
+                % working_copy.path.get()
+            )
+            raise
 
-            working_copy_path = working_copy.get_path()
+        working_copy_path = working_copy.get_path()
 
-            if reference_name is None:
-                # Create working copy from scratch
-                file_path = self.get_template_path()
-                self.root().session().log_debug(
-                    "Copy template {} to {}".format(file_path, working_copy_path)
-                )
-            else:
-                reference = self.get_revision(reference_name)
-                file_path = reference.get_path()
+        if reference_name is None:
+            # Create working copy from scratch
+            file_path = self.get_template_path()
+            self.root().session().log_debug(
+                "Copy template {} to {}".format(file_path, working_copy_path)
+            )
+        else:
+            reference = self.get_revision(reference_name)
+            file_path = reference.get_path()
 
-                self.root().session().log_debug(
-                    "Copy current revision {} to {}".format(
-                        file_path, working_copy_path
-                    )
+            self.root().session().log_debug(
+                "Copy current revision {} to {}".format(
+                    file_path, working_copy_path
                 )
+            )
 
-            try:
-                shutil.copy2(file_path, working_copy_path)
-            except OSError:
-                self.root().session().log_error(
-                    "Copy of template '{}' failed\n\n==> TRACEBACK\n".format(file_path)
-                )
-                raise
+        try:
+            shutil.copy2(file_path, working_copy_path)
+        except OSError:
+            self.root().session().log_error(
+                "Copy of template '{}' failed\n\n==> TRACEBACK\n".format(file_path)
+            )
+            raise
 
         return working_copy
 
@@ -1199,47 +1357,40 @@ class TrackedFile(File):
         working_copy = self.get_working_copy()
         working_copy_path = working_copy.get_path()
 
-        enable_os = (
-            self.root().project().admin.enable_filesystem_operations.get()
-        )  # Lovely
+        self.root().session().log_debug(
+            "Create head revision folder {}".format(head_revision.path.get())
+        )
 
-        if enable_os:
-            self.root().session().log_debug(
-                "Create head revision folder {}".format(head_revision.path.get())
-            )
-
-            try:
-                os.mkdir(head_revision.path.get())
-            except OSError:
-                self.root().session().log_error(
-                    "Creation of head revision folder '{}' failed\n\n==> TRACEBACK\n".format(
-                        head_revision.path.get()
-                    )
+        try:
+            os.mkdir(head_revision.path.get())
+        except OSError:
+            self.root().session().log_error(
+                "Creation of head revision folder '{}' failed\n\n==> TRACEBACK\n".format(
+                    head_revision.path.get()
                 )
-                raise
+            )
+            raise
 
         if keep_editing:
-            if enable_os:
-                self.root().session().log_debug(
-                    "Copy working copy {} to {}".format(
-                        working_copy_path, head_revision_path
-                    )
+            self.root().session().log_debug(
+                "Copy working copy {} to {}".format(
+                    working_copy_path, head_revision_path
                 )
+            )
 
-                shutil.copy2(working_copy_path, head_revision_path)
+            shutil.copy2(working_copy_path, head_revision_path)
         else:
-            if enable_os:
-                self.root().session().log_debug(
-                    "Copy working copy {} to {}".format(
-                        working_copy_path, head_revision_path
-                    )
-                )
-                self.root().session().log_debug(
-                    "Remove working copy folder {}".format(working_copy.path.get())
+            self.root().session().log_debug(
+                "Copy working copy {} to {}".format(
+                    working_copy_path, head_revision_path
                 )
+            )
+            self.root().session().log_debug(
+                "Remove working copy folder {}".format(working_copy.path.get())
+            )
 
-                shutil.move(working_copy_path, head_revision_path)
-                shutil.rmtree(working_copy.path.get())
+            shutil.move(working_copy_path, head_revision_path)
+            shutil.rmtree(working_copy.path.get())
 
             revisions.remove(working_copy.name())
 
@@ -1255,39 +1406,34 @@ class TrackedFile(File):
         current_path, current_name = self.get_current_revision_params()
         current_revision_path = os.path.join(current_path, current_name)
 
-        enable_os = (
-            self.root().project().admin.enable_filesystem_operations.get()
-        )  # Lovely
-
         if not os.path.exists(current_path):
             os.makedirs(current_path)
 
-        if enable_os:
+        try:
+            # TODO: make it work
+            self.root().session().log_debug(
+                "Create symlink {} pointing to {}".format(
+                    revision.path.get(), current_path
+                )
+            )
+            os.symlink(revision.path.get(), current_path, target_is_directory=True)
+        except OSError:
+            self.root().session().log_warning("Symbolic link privilege not held...")
+
             try:
-                # TODO: make it work
                 self.root().session().log_debug(
-                    "Create symlink {} pointing to {}".format(
-                        revision.path.get(), current_path
+                    "Copy working copy {} to {}".format(
+                        revision_path, current_revision_path
                     )
                 )
-                os.symlink(revision.path.get(), current_path, target_is_directory=True)
+                shutil.copy2(revision_path, current_revision_path)
             except OSError:
-                self.root().session().log_warning("Symbolic link privilege not held...")
-
-                try:
-                    self.root().session().log_debug(
-                        "Copy working copy {} to {}".format(
-                            revision_path, current_revision_path
-                        )
+                self.root().session().log_error(
+                    "Copy of head revision '{}' to current failed".format(
+                        revision_path
                     )
-                    shutil.copy2(revision_path, current_revision_path)
-                except OSError:
-                    self.root().session().log_error(
-                        "Copy of head revision '{}' to current failed".format(
-                            revision_path
-                        )
-                    )
-                    raise
+                )
+                raise
 
         self.current_revision.set(revision.name())
         self.get_revisions().touch()
@@ -1710,7 +1856,6 @@ class FileSystemMap(flow.Map):
     create_folder = flow.Child(CreateTrackedFolderAction).injectable()
     create_untracked_folder = flow.Child(CreateFolderAction)
     create_untracked_file = flow.Child(CreateFileAction)
-    clear_map = flow.Child(ClearFileSystemMapAction).ui(hidden=True)
 
     @classmethod
     def mapped_type(cls):
@@ -1798,40 +1943,38 @@ class FileSystemMap(flow.Map):
         file = self.add(key, object_type=File)
         file.format.set(extension)
 
-        if self.root().project().admin.enable_filesystem_operations.get():
-            # Create file's parent folder
-            parent_folder = os.path.abspath(os.path.join(file.get_path(), ".."))
-            try:
-                os.makedirs(parent_folder)
-            except OSError:
-                # Folder already created
-                pass
+        # Create file's parent folder
+        parent_folder = os.path.abspath(os.path.join(file.get_path(), ".."))
+        try:
+            os.makedirs(parent_folder)
+        except OSError:
+            # Folder already created
+            pass
 
-            # Create file from template
-            try:
-                shutil.copyfile(file.get_template_path(), file.get_path())
-            except OSError:
-                self.root().session().log_error(
-                    "File %s already exists" % file.get_path()
-                )
-                raise
+        # Create file from template
+        try:
+            shutil.copyfile(file.get_template_path(), file.get_path())
+        except OSError:
+            self.root().session().log_error(
+                "File %s already exists" % file.get_path()
+            )
+            raise
 
         return file
 
     def add_folder(self, name):
         folder = self.add(name, object_type=Folder)
 
-        if self.root().project().admin.enable_filesystem_operations.get():
-            try:
-                if os.path.exists(folder.get_path()):
-                    print("Folder %s already exists" % folder.get_path())
-                else:
-                    os.makedirs(folder.get_path())
-            except OSError:
-                self.root().session().log_error(
-                    "Error while creating folder %s" % folder.get_path()
-                )
-                raise
+        try:
+            if os.path.exists(folder.get_path()):
+                print("Folder %s already exists" % folder.get_path())
+            else:
+                os.makedirs(folder.get_path())
+        except OSError:
+            self.root().session().log_error(
+                "Error while creating folder %s" % folder.get_path()
+            )
+            raise
 
         return folder
 
@@ -1841,36 +1984,35 @@ class FileSystemMap(flow.Map):
         file.format.set(extension)
         file.complete_name.set(complete_name)
 
-        if self.root().project().admin.enable_filesystem_operations.get():
-            # Create file folder
-            try:
-                self.root().session().log_debug(
-                    "Create file folder '{}'".format(file.get_path())
-                )
-                os.makedirs(file.get_path())
-            except OSError:
-                self.root().session().log_error(
-                    "Creation of file folder '{}' failed.".format(file.get_path())
-                )
-                pass
+        # Create file folder
+        try:
+            self.root().session().log_debug(
+                "Create file folder '{}'".format(file.get_path())
+            )
+            os.makedirs(file.get_path())
+        except OSError:
+            self.root().session().log_error(
+                "Creation of file folder '{}' failed.".format(file.get_path())
+            )
+            pass
 
-            # Create current revision folder
-            current_revision_folder = os.path.join(file.get_path(), "current")
+        # Create current revision folder
+        current_revision_folder = os.path.join(file.get_path(), "current")
 
-            try:
-                self.root().session().log_debug(
-                    "Create current revision folder '{}'".format(
-                        current_revision_folder
-                    )
+        try:
+            self.root().session().log_debug(
+                "Create current revision folder '{}'".format(
+                    current_revision_folder
                 )
-                os.mkdir(current_revision_folder)
-            except OSError:
-                self.root().session().log_error(
-                    "Creation of current revision folder '{}' failed".format(
-                        current_revision_folder
-                    )
+            )
+            os.mkdir(current_revision_folder)
+        except OSError:
+            self.root().session().log_error(
+                "Creation of current revision folder '{}' failed".format(
+                    current_revision_folder
                 )
-                pass
+            )
+            pass
 
         return file
 
@@ -1879,51 +2021,49 @@ class FileSystemMap(flow.Map):
         folder.format.set("zip")
         folder.complete_name.set(complete_name)
 
-        if self.root().project().admin.enable_filesystem_operations.get():
-            # Create file folder
-            try:
-                self.root().session().log_debug(
-                    "Create tracked folder '{}'".format(folder.get_path())
-                )
-                os.makedirs(folder.get_path())
-            except OSError:
-                self.root().session().log_error(
-                    "Creation of tracked folder '{}' failed.".format(folder.get_path())
-                )
-                pass
+        # Create file folder
+        try:
+            self.root().session().log_debug(
+                "Create tracked folder '{}'".format(folder.get_path())
+            )
+            os.makedirs(folder.get_path())
+        except OSError:
+            self.root().session().log_error(
+                "Creation of tracked folder '{}' failed.".format(folder.get_path())
+            )
+            pass
 
-            # Create current revision folder
-            current_revision_folder = os.path.join(folder.get_path(), "current")
+        # Create current revision folder
+        current_revision_folder = os.path.join(folder.get_path(), "current")
 
-            try:
-                self.root().session().log_debug(
-                    "Create current revision folder '{}'".format(
-                        current_revision_folder
-                    )
+        try:
+            self.root().session().log_debug(
+                "Create current revision folder '{}'".format(
+                    current_revision_folder
                 )
-                os.mkdir(current_revision_folder)
-            except OSError:
-                self.root().session().log_error(
-                    "Creation of current revision folder '{}' failed".format(
-                        current_revision_folder
-                    )
+            )
+            os.mkdir(current_revision_folder)
+        except OSError:
+            self.root().session().log_error(
+                "Creation of current revision folder '{}' failed".format(
+                    current_revision_folder
                 )
-                pass
+            )
+            pass
 
         return folder
 
     def clear(self):
-        if self.root().project().admin.enable_filesystem_operations.get():
-            for item in self.mapped_items():
-                try:
-                    if type(item) is File:
-                        os.remove(item.get_path())
-                    else:
-                        shutil.rmtree(item.get_path())
-                except FileNotFoundError:
-                    self.root().session().log_warning(
-                        "%s %s no longer exists"
-                        % (item.__class__.__name__, item.get_path())
-                    )
+        for item in self.mapped_items():
+            try:
+                if type(item) is File:
+                    os.remove(item.get_path())
+                else:
+                    shutil.rmtree(item.get_path())
+            except FileNotFoundError:
+                self.root().session().log_warning(
+                    "%s %s no longer exists"
+                    % (item.__class__.__name__, item.get_path())
+                )
 
         super(FileSystemMap, self).clear()
